@@ -386,7 +386,8 @@ SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *eng
 
 SensorFaceController::~SensorFaceController()
 {
-    if (!d->shouldSync) {
+    auto forceSave = d->faceProperties.readEntry(QStringLiteral("ForceSaveOnDestroy"), false);
+    if (!d->shouldSync && !forceSave) {
         // If we should not sync automatically, clear all changes before we
         // destroy the config objects, otherwise they will be written during
         // destruction.
